@@ -285,10 +285,10 @@ enum Platform { PF_UNKNOWN, PF_X86, PF_X64, PF_IA64, PF_ARM64 };
 
 	#define NPPM_RELOADFILE (NPPMSG + 36)
 	// BOOL NPPM_RELOADFILE(BOOL withAlert, TCHAR *filePathName2Reload)
-	// Reload the document which matches with the given filePathName2switch.
+	// Reload the document which matches with the given filePathName2Reload.
 	// wParam: 0 (not used)
 	// lParam[in]: filePathName2Reload is the full file path of document to reload 
-	// Return TRUE
+	// Return TRUE if reloading file succeeds, otherwise FALSE
 
 	#define NPPM_SWITCHTOFILE (NPPMSG + 37)
 	// BOOL NPPM_SWITCHTOFILE(0, TCHAR* filePathName2switch)
@@ -1047,7 +1047,7 @@ enum Platform { PF_UNKNOWN, PF_X86, PF_X64, PF_IA64, PF_ARM64 };
 	//scnNotification->nmhdr.idFrom = BufferID;
 
 	#define NPPN_FILEBEFORESAVE (NPPN_FIRST + 7) // To notify plugins that the current file is about to be saved
-	//scnNotification->nmhdr.code = NPPN_FILEBEFOREOPEN;
+	//scnNotification->nmhdr.code = NPPN_FILEBEFORESAVE;
 	//scnNotification->nmhdr.hwndFrom = hwndNpp;
 	//scnNotification->nmhdr.idFrom = BufferID;
 
@@ -1077,7 +1077,7 @@ enum Platform { PF_UNKNOWN, PF_X86, PF_X64, PF_IA64, PF_ARM64 };
 	//scnNotification->nmhdr.idFrom = currentBufferID;
 
 	#define NPPN_SHORTCUTREMAPPED (NPPN_FIRST + 13) // To notify plugins that plugin command shortcut is remapped.
-	//scnNotification->nmhdr.code = NPPN_SHORTCUTSREMAPPED;
+	//scnNotification->nmhdr.code = NPPN_SHORTCUTREMAPPED;
 	//scnNotification->nmhdr.hwndFrom = ShortcutKeyStructurePointer;
 	//scnNotification->nmhdr.idFrom = cmdID;
 		//where ShortcutKeyStructurePointer is pointer of struct ShortcutKey:
@@ -1089,12 +1089,12 @@ enum Platform { PF_UNKNOWN, PF_X86, PF_X64, PF_IA64, PF_ARM64 };
 		//};
 
 	#define NPPN_FILEBEFORELOAD (NPPN_FIRST + 14) // To notify plugins that the current file is about to be loaded
-	//scnNotification->nmhdr.code = NPPN_FILEBEFOREOPEN;
+	//scnNotification->nmhdr.code = NPPN_FILEBEFORELOAD;
 	//scnNotification->nmhdr.hwndFrom = hwndNpp;
 	//scnNotification->nmhdr.idFrom = NULL;
 
 	#define NPPN_FILELOADFAILED (NPPN_FIRST + 15)  // To notify plugins that file open operation failed
-	//scnNotification->nmhdr.code = NPPN_FILEOPENFAILED;
+	//scnNotification->nmhdr.code = NPPN_FILELOADFAILED;
 	//scnNotification->nmhdr.hwndFrom = hwndNpp;
 	//scnNotification->nmhdr.idFrom = BufferID;
 
@@ -1172,3 +1172,11 @@ enum Platform { PF_UNKNOWN, PF_X86, PF_X64, PF_IA64, PF_ARM64 };
 	//scnNotification->nmhdr.code = NPPN_EXTERNALLEXERBUFFER;
 	//scnNotification->nmhdr.hwndFrom = hwndNpp;
 	//scnNotification->nmhdr.idFrom = BufferID; //where pluginMessage is pointer of type wchar_t
+
+	#define NPPN_GLOBALMODIFIED (NPPN_FIRST + 30)  // To notify plugins that the current document is just modified by Replace All action.
+                                                   // For solving the performance issue (from v8.6.4), Notepad++ doesn't trigger SCN_MODIFIED during Replace All action anymore.
+                                                   // As a result, the plugins which monitor SCN_MODIFIED should also monitor NPPN_GLOBALMODIFIED.
+                                                   // This notification is implemented in Notepad++ v8.6.5.
+	//scnNotification->nmhdr.code = NPPN_GLOBALMODIFIED;
+	//scnNotification->nmhdr.hwndFrom = BufferID;
+	//scnNotification->nmhdr.idFrom = 0; // preserved for the future use, must be zero
